package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.ContributeArticleVO;
import com.unis.indicator.server.service.ContributeArticleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.Map;

/**
 * @ClassName ContributeArticleController
 * @Description 文章投稿标准管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "文章投稿管理controller")
public class ContributeArticleController {

    @Autowired
    private ContributeArticleService contributeArticleService;

    /**
     * @Description: 通过id查询文章投稿信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询文章投稿信息", notes = "参数：文章投稿信息id")
    @GetMapping(value = "/contributeArticle/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        ContributeArticleVO resVO = contributeArticleService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    /**
     * @Description: 保存文章投稿信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存文章投稿信息", notes = "参数：文章投稿对象VO")
    @PostMapping(value = "/contributeArticle/")
    public ResponseWrapper save(@RequestBody ContributeArticleVO VO) throws Exception {
        boolean flag = contributeArticleService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新文章投稿信息", notes = "参数：文章投稿VO")
    @PutMapping(value = "/contributeArticle/")
    public ResponseWrapper update(@RequestBody ContributeArticleVO VO) throws Exception {

        boolean flag = contributeArticleService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    @ApiOperation(value = "提交文章投稿信息", notes = "参数：文章投稿id")
    @PutMapping(value = "/contributeArticle/sub/")
    public ResponseWrapper submit(@RequestBody ContributeArticleVO VO) throws Exception {

        boolean flag = contributeArticleService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "提交对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    @ApiOperation(value = "发布文章投稿信息", notes = "参数：文章投稿id")
    @PutMapping(value = "/contributeArticle/pub/")
    public ResponseWrapper publish(@RequestBody ContributeArticleVO VO) throws Exception {

        boolean flag = contributeArticleService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "发布对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除文章投稿
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除文章投稿", notes = "参数：文章投稿id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/contributeArticles")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = contributeArticleService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除文章投稿失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 查询所有文章投稿
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有文章投稿，分页", notes = "参数：文章投稿名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true),
            @ApiImplicitParam(name = "isUser", value = "是否是上报人员，0：是；1：不是", required = true)})
    @PostMapping(value = "/contributeArticles")
    public ResponseWrapper findByPage(@RequestBody ContributeArticleVO VO,
                                      Integer page,
                                      Integer size,
                                      String isUser) throws Exception {
        Map<String, Object> result = contributeArticleService.findByPage(VO, page, size, isUser);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    /**
     * @Description: 查询所有文章投稿
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有文章投稿，分页By", notes = "参数：文章投稿名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true),
            @ApiImplicitParam(name = "isUser", value = "是否是上报人员，0：是；1：不是", required = true)})
    @PostMapping(value = "/contributeArticlesBy")
    public ResponseWrapper findByPageBy(@RequestBody ContributeArticleVO VO,
                                      Integer page,
                                      Integer size,
                                      String isUser) throws Exception {
        Map<String, Object> result = contributeArticleService.findByPageBy(VO, page, size, isUser);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    /**
     * @Description: 查询所有文章投稿
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
//    @ApiOperation(value = "查询所有文章投稿，不分页", notes = "参数：无")
//    @GetMapping(value = "/contributeArticles")
//    public ResponseWrapper findAll() throws Exception {
//        Map<String, Object> result = contributeArticleService.findByPage(new ContributeArticleVO(),1, 999, "0");
//        return ResponseWrapper.success(
//                HttpStatus.OK.value(),
//                HttpStatus.OK.getReasonPhrase(),
//                result);
//    }

    /**
     * @Description: 查询文章汇总
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "文章汇总,分页", notes = "参数：监测点名、日期from、日期to、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/articleGathers")
    public ResponseWrapper articleGathers(@RequestBody ContributeArticleVO VO,
                                          Integer page,
                                          Integer size) throws Exception {
        Map<String, Object> result = contributeArticleService.articleGather(VO,page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "文章汇总,查看", notes = "参数：机构id、创建时间、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @GetMapping(value = "/articles")
    public ResponseWrapper articles(String orgId,
                                         String dateFrom,
                                         String dateTo,
                                         Integer page,
                                         Integer size) throws Exception {
        Map<String, Object> result = contributeArticleService.articles(orgId,dateFrom,dateTo, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }
    
	/**
	 * 
	 * @Description: 方法描述
	 * @author: 王帅
	 * @param: @param  id
	 * @param: @param  status
	 * @param: @return
	 * @param: @throws Exception 参数
	 * @return: boolean 返回类型
	 */
	@ApiOperation(value = "修改投稿状态", notes = "修改投稿状态")
	@ApiImplicitParams({ @ApiImplicitParam(name = "id", value = "主键", paramType = "query", required = true),
			@ApiImplicitParam(name = "status", value = "状态(默认为：1 已提交)", paramType = "query", required = true, defaultValue = "1") })
	@GetMapping("modification/article/status")
	public ResponseWrapper updateArticleStatus(@RequestParam(value = "id", required = true) String id,
			@RequestParam(value = "status", required = true, defaultValue = "1") String status) {
		try {
			boolean result = contributeArticleService.updateArticleStatus(id, status);
			if (result) {
				return ResponseWrapper.success(HttpStatus.OK.value(), "修改状态成功", null);
			}
		} catch (Exception e) {
			System.out.println(e.getMessage());
		}
		return ResponseWrapper.error(HttpStatus.INTERNAL_SERVER_ERROR.value(),
				HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(), "修改投稿状态失败！");
	}
}
