package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.IndicatorMonitorVO;
import com.unis.indicator.common.vo.IndicatorPriceVO;
import com.unis.indicator.common.vo.IndicatorStandardVO;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.server.service.IndicatorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName IndicatorController
 * @Description 指标管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "指标管理controller")
public class IndicatorController {

    @Autowired
    private IndicatorService indicatorService;

    /**
     * @Description: 通过id查询指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询指标信息", notes = "参数：指标信息id")
    @GetMapping(value = "/indicator/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        IndicatorVO resVO = indicatorService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    @ApiOperation(value = "通过indicatorId查询指标和监测点关联信息", notes = "参数：指标信息id")
    @GetMapping(value = "/indMonRel/{indicatorId}/")
    public ResponseWrapper findIndMonRel(@PathVariable("indicatorId") String indicatorId) throws Exception {
        boolean res = indicatorService.findIndMonRel(indicatorId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    /**
     * @Description: 保存指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存指标信息", notes = "参数：指标对象VO")
    @PostMapping(value = "/indicator/")
    public ResponseWrapper save(@RequestBody IndicatorVO VO) throws Exception {
        boolean flag = indicatorService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新执法人员信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新指标信息", notes = "参数：指标VO")
    @PutMapping(value = "/indicator/")
    public ResponseWrapper update(@RequestBody IndicatorVO VO) throws Exception {

        boolean flag = indicatorService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除指标
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除指标", notes = "参数：指标id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/indicators")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = indicatorService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除指标失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 查询所有用户
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标", notes = "参数：指标名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/indicators")
    public ResponseWrapper findByPage(@RequestBody IndicatorVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = indicatorService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 查询所有用户(按品种分组)
     * @date 2019/12/17 16:03
     * @author yangshengjie
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有指标(按品种分组)", notes = "参数：当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/indicatorsGroup")
    public ResponseWrapper findByPageGroup(@RequestBody IndicatorVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        List result = indicatorService.findByPageGroup(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "查询所有指标，不分页", notes = "参数：无")
    @GetMapping(value = "/indicators")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = indicatorService.findByPage(new IndicatorVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 获取所有指标类型信息树形结构
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "获取指标信息树形结构", notes = "参数：treeCode(0：所有的指标树；1：父级指标树)")
    @GetMapping(value = "/indicatorsTree")
    public ResponseWrapper pIndicatorsTree(String treeCode) throws Exception {
        List<IndicatorVO> res = indicatorService.findIndsTree(treeCode);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    /**
     * @Description: 指标与监测点关联保存
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "指标与监测点关联保存", notes = "参数：监测点与指标关联Model")
    @PostMapping(value = "/indicatorMonitor/")
    public ResponseWrapper saveIndicatorMonitor(@RequestBody IndicatorMonitorVO VO) throws Exception {
        boolean flag = indicatorService.saveIndicatorMonitor(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 查询监测点对应勾选了的指标
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询监测点对应勾选了的指标", notes = "参数：监测点id")
    @GetMapping(value = "/indicatorMonitor/")
    public ResponseWrapper findIndicatorMonitor(String monitorId) throws Exception {
        IndicatorMonitorVO res = indicatorService.findIndicatorMonitor(monitorId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    @ApiOperation(value = "指标标准与指标保存", notes = "参数：指标标准与指标关联Model")
    @PostMapping(value = "/indicatorStandard/")
    public ResponseWrapper saveIndicatorStandard(@RequestBody IndicatorStandardVO VO) throws Exception {
        boolean flag = indicatorService.saveIndicatorStandard(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    @ApiOperation(value = "查询指标对应勾选了的指标标准", notes = "参数：指标id")
    @GetMapping(value = "/indicatorStandard/")
    public ResponseWrapper findIndicatorStandard(String indicatorId) throws Exception {
        IndicatorStandardVO res = indicatorService.findIndicatorStandard(indicatorId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    @ApiOperation(value = "价格类型与指标保存", notes = "参数：价格类型与指标关联Model")
    @PostMapping(value = "/indicatorPriceType/")
    public ResponseWrapper saveIndicatorPriceType(@RequestBody IndicatorPriceVO VO) throws Exception {
        boolean flag = indicatorService.saveIndicatorPriceType(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    @ApiOperation(value = "查询指标对应勾选了的价格类型", notes = "参数：指标id")
    @GetMapping(value = "/indicatorPriceType/")
    public ResponseWrapper findIndicatorPriceType(String indicatorId) throws Exception {
        IndicatorPriceVO res = indicatorService.findIndicatorPriceType(indicatorId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }
}
