package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.PriceTypeVO;
import com.unis.indicator.server.service.PriceTypeService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName PriceTypeController
 * @Description 价格监测controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "价格类型controller")
public class PriceTypeController {

    @Autowired
    private PriceTypeService priceTypeService;

    /**
     * @Description: 通过id查询价格类型信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询价格类型信息", notes = "参数：价格类型信息id")
    @GetMapping(value = "/priceType/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        PriceTypeVO resVO = priceTypeService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    @ApiOperation(value = "通过priceTypeId查询指标与价格类型关联信息", notes = "参数：价格类型信息id")
    @GetMapping(value = "/priceTypeIndRel/{priceTypeId}/")
    public ResponseWrapper findPriceTypeIndRel(@PathVariable("priceTypeId") String priceTypeId) throws Exception {
        boolean res = priceTypeService.findPriceTypeIndRel(priceTypeId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    /**
     * @Description: 保存价格类型信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存价格类型信息", notes = "参数：价格类型对象VO")
    @PostMapping(value = "/priceType/")
    public ResponseWrapper save(@RequestBody PriceTypeVO VO) throws Exception {
        boolean flag = priceTypeService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新价格类型信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新价格类型信息", notes = "参数：价格类型VO")
    @PutMapping(value = "/priceType/")
    public ResponseWrapper update(@RequestBody PriceTypeVO VO) throws Exception {

        boolean flag = priceTypeService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除价格类型
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除价格类型", notes = "参数：价格类型id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/priceTypes")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = priceTypeService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除价格类型失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 价格类型
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有价格类型,分页", notes = "参数：价格类型名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/priceTypes")
    public ResponseWrapper findByPage(@RequestBody PriceTypeVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = priceTypeService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "查询所有价格类型，不分页", notes = "参数：无")
    @GetMapping(value = "/priceTypes")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = priceTypeService.findByPage(new PriceTypeVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "查询权重的价格类型", notes = "参数：无")
    @GetMapping(value = "/priceWeightTypes")
    public ResponseWrapper findPriceWeightTypes() throws Exception {
        List<PriceTypeVO> result = priceTypeService.findPriceWeightTypes();
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

}
