package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.bbzb.ReportConfigVO;
import com.unis.indicator.common.vo.bbzb.ReportIndicatorVO;
import com.unis.indicator.server.service.ReportIndicatorService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName ZkbbzbController
 * @Description 报表指标管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "报表指标管理controller")
public class ReportIndicatorController {

    @Autowired
    private ReportIndicatorService bbzbService;

    /**
     * @Description: 通过id查询报表指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询报表指标信息", notes = "参数：报表指标信息id")
    @GetMapping(value = "/reportIndicator/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        ReportIndicatorVO resVO = bbzbService.findById(id);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    /**
     * @Description: 通过id查询报表指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param reportTypeId
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据报表id查询指标集合", notes = "参数：报表id")
    @GetMapping(value = "/indicators/{reportTypeId}/")
    public ResponseWrapper findByReportTypeId(@PathVariable("reportTypeId") String reportTypeId) throws Exception {
        List<IndicatorVO> res = bbzbService.findByReportTypeId(reportTypeId);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                res);
    }

    /**
     * @Description: 保存报表指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存报表指标信息", notes = "参数：报表指标对象VO")
    @PostMapping(value = "/reportIndicator/")
    public ResponseWrapper save(@RequestBody ReportIndicatorVO VO) throws Exception {
        boolean flag = bbzbService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新报表指标信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新报表指标信息", notes = "参数：报表指标VO")
    @PutMapping(value = "/reportIndicator/")
    public ResponseWrapper update(@RequestBody ReportIndicatorVO VO) throws Exception {

        boolean flag = bbzbService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除报表指标
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除报表指标", notes = "参数：报表指标id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/reportIndicators")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = bbzbService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除报表指标失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 报表指标
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有报表指标，分页", notes = "参数：报表类型名,指标名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/reportIndicators")
    public ResponseWrapper findByPage(@RequestBody ReportIndicatorVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = bbzbService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 报表指标
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有报表指标，不分页", notes = "参数：无")
    @GetMapping(value = "/reportIndicators")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = bbzbService.findByPage(new ReportIndicatorVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 报表指标
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询报表指标的配置", notes = "参数：ReportConfigVO需要填写报表类型编码/报表指标编码/报表价格编码/监测点编码")
    @PostMapping(value = "/reportConfigRecord/")
    public ResponseWrapper findBbpz(@RequestBody ReportConfigVO vo) throws Exception {
        ReportConfigVO result = bbzbService.findZkbbpz(vo);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 保存报表配置信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存报表配置信息", notes = "参数：报表指标对象VO，信息都需要填写，监测点所属地区名称不需要填写，后台会根据传过来的监测点所属地区编码进行转换。")
    @PostMapping(value = "/reportConfig/")
    public ResponseWrapper saveReportConfig(@RequestBody ReportConfigVO VO) throws Exception {
        boolean flag = bbzbService.saveOrUpdateZkbbpz(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }
}
