package com.unis.indicator.server.controller;

import com.unis.common.utils.ResponseWrapper;
import com.unis.common.utils.UUIDUtils;
import com.unis.indicator.common.vo.IndicatorVO;
import com.unis.indicator.common.vo.WeightVO;
import com.unis.indicator.common.vo.WeightValueVO;
import com.unis.indicator.server.entity.indicator.QzzDO;
import com.unis.indicator.server.service.WeightService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * @ClassName WeightController
 * @Description 权重管理controller
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@RestController
@Slf4j
@Api(tags = "权重管理controller")
public class WeightController {

    @Autowired
    private WeightService weightService;

    /**
     * @Description: 通过id查询权重信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param id
     * @return ResponseWrapper
     */
    @ApiOperation(value = "根据id查询权重信息", notes = "参数：权重信息id")
    @GetMapping(value = "/weight/{id}/")
    public ResponseWrapper findById(@PathVariable("id") String id) throws Exception {
        WeightVO resVO = weightService.findById(id);
        List<WeightValueVO> result = weightService.findWeightValByWeightCode(resVO.getWeightCode());
        resVO.setWeightValueList(result);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                resVO);
    }

    /**
     * @Description: 保存权重信息
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "保存权重信息", notes = "参数：权重对象VO")
    @PostMapping(value = "/weight/")
    public ResponseWrapper save(@RequestBody WeightVO VO) throws Exception {
        boolean flag = weightService.save(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "对象已存在无法添加");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 更新
     * @date 2019年7月24日,下午5:54:00
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @return ResponseWrapper
     */
    @ApiOperation(value = "更新权重信息", notes = "参数：权重VO")
    @PutMapping(value = "/weight/")
    public ResponseWrapper update(@RequestBody WeightVO VO) throws Exception {

        boolean flag = weightService.update(VO);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "更新对象失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 删除权重
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param ids
     * @return ResponseWrapper
     */
    @ApiOperation(value = "删除权重", notes = "参数：权重id(可传入多个), 操作用户id")
    @DeleteMapping(value = "/weights")
    public ResponseWrapper deletes(@RequestBody String[] ids, String userId) throws Exception {
        boolean flag = weightService.deletes(ids, userId);
        if (!flag) {
            return ResponseWrapper.error(
                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
                    "删除权重失败");
        }
        return  ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                null);
    }

    /**
     * @Description: 权重
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @param VO
     * @param page
     * @param size
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有权重，分页", notes = "参数：权重名模糊查询、当前页、页面大小")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "page", value = "起始页", required = true),
            @ApiImplicitParam(name = "size", value = "每页展示行数", required = true) })
    @PostMapping(value = "/weights")
    public ResponseWrapper findByPage(@RequestBody WeightVO VO,
                                      Integer page,
                                      Integer size) throws Exception {
        Map<String, Object> result = weightService.findByPage(VO, page, size);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    /**
     * @Description: 权重
     * @date 2019年7月24日,下午8:35:41
     * @author xmpu
     * @version v1.0
     *
     * @return ResponseWrapper
     */
    @ApiOperation(value = "查询所有权重，不分页", notes = "参数：无")
    @GetMapping(value = "/weights")
    public ResponseWrapper findAll() throws Exception {
        Map<String, Object> result = weightService.findByPage(new WeightVO(), 1, 999);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "通过权重code查询权重值信息", notes = "参数：权重code")
    @GetMapping(value = "/weightValsByCode/{weightCode}/")
    public ResponseWrapper findWeightValByWeightCode(@PathVariable("weightCode") String weightCode) throws Exception {
        List<WeightValueVO> result = weightService.findWeightValByWeightCode(weightCode);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "通过权重type查询权重值信息", notes = "参数：权重type")
    @GetMapping(value = "/weightValsByType/{weightType}/")
    public ResponseWrapper findWeightValByWeightType(@PathVariable("weightType") String weightType) throws Exception {
        List<IndicatorVO> result = weightService.findWeightValByWeightType(weightType);
        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                result);
    }

    @ApiOperation(value = "获取权重流水号", notes = "参数：无")
    @GetMapping(value = "/serialNumber/")
    public ResponseWrapper serialNumber() {

        return ResponseWrapper.success(
                HttpStatus.OK.value(),
                HttpStatus.OK.getReasonPhrase(),
                "QZ" + UUIDUtils.uuid());
    }

//    @ApiOperation(value = "保存权重值信息", notes = "参数：权重值对象集合")
//    @PostMapping(value = "/weightVals")
//    public ResponseWrapper saveWeightVals(@RequestBody List<WeightValueVO> VOList, String weightCode) throws Exception {
//        boolean flag = weightService.saveWeightVal(VOList, weightCode);
//        if (!flag) {
//            return ResponseWrapper.error(
//                    HttpStatus.INTERNAL_SERVER_ERROR.value(),
//                    HttpStatus.INTERNAL_SERVER_ERROR.getReasonPhrase(),
//                    "权重值无法添加");
//        }
//        return  ResponseWrapper.success(
//                HttpStatus.OK.value(),
//                HttpStatus.OK.getReasonPhrase(),
//                null);
//    }
}
