package com.unis.indicator.server.domain;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.unis.common.utils.DateUtil;
import com.unis.common.utils.LsBeanUtils;
import com.unis.common.utils.UUIDUtils;
import com.unis.common.utils.ValidationUtil;
import com.unis.indicator.common.vo.JournalVO;
import com.unis.indicator.server.config.SecurityUtil;
import com.unis.indicator.server.dao.QkscDao;
import com.unis.indicator.server.entity.QkscDO;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import tk.mybatis.mapper.entity.Example;

import java.util.*;

/**
 * @ClassName JournalDomain
 * @Description 期刊领域对象
 * @Author xmpu
 * @Date 2019/7/24 17:07
 * @Version 0.0.1
 **/
@Getter
@Setter
@Component
public class JournalDomain {

	@Autowired
	private QkscDao dao;

	/**
	 *
	 * @Description: 通过id查询期刊信息
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param id
	 * @return QkscDO
	 */
	public QkscDO findJournalById(String id) throws Exception {
		Example example = new Example(QkscDO.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIsNull("deleteTime");
		criteria.andEqualTo("id", id);
		QkscDO resDO = dao.selectOneByExample(example);
		if (ObjectUtils.equals(resDO, null)) {
			return null;
		}
		return resDO;
	}

	/**
	 *
	 * @Description: 查询所有期刊信息 模糊查询的条件可以包含：名称
	 * @date 2019年7月24日,下午5:54:00
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @param page
	 * @param size
	 * @return Map
	 * @throws Exception
	 */
	public Map<String, Object> findJournalsByPage(JournalVO VO, Integer page, Integer size) throws Exception {

		Example example = new Example(QkscDO.class);
		Example.Criteria criteria = example.createCriteria();
		String	title= SecurityUtil.filterStrSqlJs(VO.getTitle());

		// 添加按名称查询
		if (!"".equals(title) && null !=title) {
			criteria.andLike("title", "%" + title + "%");
		}
		// 未删除
		criteria.andIsNull("deleteTime");
		PageHelper.startPage(page, size, "CREATE_TIME DESC");
		List<QkscDO> resultDOList = dao.selectByExample(example);
		PageInfo<QkscDO> pageInfo = new PageInfo<QkscDO>(resultDOList);

		Map<String, Object> resultMap = new HashMap<String, Object>();
		List<JournalVO> resultVOList = new ArrayList<>();
		if (!resultDOList.isEmpty()) {
			for (QkscDO resultDO : resultDOList) {
				JournalVO resultVO = LsBeanUtils.copyProperties(resultDO, JournalVO.class);
				resultVOList.add(resultVO);
			}
		}
		resultMap.put("total", pageInfo.getTotal());
		resultMap.put("resultList", resultVOList);
		return resultMap;
	}

	/**
	 *
	 * @Description: 期刊多选删除
	 * @date 2019年7月24日,下午8:58:47
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param ids
	 * @param userId
	 * @return Boolean
	 * @throws Exception
	 */
	public boolean deleteJournals(String[] ids, String userId) throws Exception {
		for (String id : ids) {
			Example example = new Example(QkscDO.class);
			Example.Criteria criteria = example.createCriteria();
			criteria.andEqualTo("id", id);
			criteria.andIsNull("deleteTime");
			QkscDO udpDO = dao.selectOneByExample(example);
			if (ObjectUtils.notEqual(udpDO, null)) {
				udpDO.setDeleteBy(userId);
				udpDO.setDeleteTime(DateUtil.getNowDate());
				dao.updateByPrimaryKey(udpDO);
			}
		}
		return true;
	}

	/**
	 *
	 * @Description: 保存期刊信息
	 * @date 2019年7月24日,下午8:58:56
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean saveJournal(JournalVO VO) throws Exception {
		ValidationUtil.validate(VO);
		Example example = new Example(QkscDO.class);
		Example.Criteria criteria = example.createCriteria();
		if (!"".equals(VO.getTitle()) && null != VO.getTitle()) {
			criteria.andEqualTo("title", VO.getTitle());
		}
		criteria.andIsNull("deleteTime");
		if (dao.selectCountByExample(example) > 0) {
			throw new RuntimeException(VO.getTitle() + "已存在");
		}
		QkscDO insDO = new QkscDO();
		LsBeanUtils.copyPropertiesIgnoreNull(VO, insDO);
		insDO.setCreateBy(VO.getOperator());
		insDO.setCreateTime(new Date());
		insDO.setId(UUIDUtils.uuid());

		if (dao.insertSelective(insDO) < 1) {
			throw new RuntimeException(insDO.getTitle() + "无法保存成功，请检查数据。");
		}
		return true;
	}

	/**
	 *
	 * @Description: 更新期刊
	 * @date 2019年7月24日,下午8:59:05
	 * @author xmpu
	 * @version v1.0
	 *
	 * @param VO
	 * @return boolean
	 * @throws Exception
	 */
	public boolean updateJournal(JournalVO VO) throws Exception {
		ValidationUtil.validate(VO);
		QkscDO udpDO = findJournalById(VO.getId());
		if (ObjectUtils.equals(udpDO, null)) {
			return false;
		}
		LsBeanUtils.copyPropertiesIgnoreNull(VO, udpDO);

		udpDO.setUpdateBy(VO.getOperator());
		udpDO.setUpdateTime(DateUtil.getNowDate());
		if (dao.updateByPrimaryKey(udpDO) < 1) {
			return false;
		}
		return true;
	}

}
